@@ -24,5 +24,3 @@ export const Request = connect(
 )(RequestComponent);
 
 export * from "./Status";
-export * from "./StatusLabel";
-export * from "./TypeLabel";
