@@ -16,6 +16,7 @@ from invenio_records_permissions.generators import (
     AuthenticatedUser,
     Disable,
     SystemProcess,
+    SystemProcessWithoutSuperUser,
 )
 
 from .generators import Commenter, Creator, Receiver, Status
@@ -62,7 +63,10 @@ class PermissionPolicy(RecordPermissionPolicy):
     # request status into account.
     can_action_submit = [Creator(), SystemProcess()]
     can_action_cancel = [Creator(), SystemProcess()]
-    can_action_expire = [SystemProcess()]
+    # `SystemProcessWithoutSuperUser`: expire is an automatic action done only by
+    # the system, therefore the `superuser-action` must be explicitly excluded
+    # as it's added by default to any permission.
+    can_action_expire = [SystemProcessWithoutSuperUser()]
     can_action_accept = [Receiver(), SystemProcess()]
     can_action_decline = [Receiver(), SystemProcess()]
 
@@ -76,6 +80,8 @@ class PermissionPolicy(RecordPermissionPolicy):
         Commenter(),
         SystemProcess(),
     ]
+    # If you can read the request you can create events for the request.
+    can_create_comment = can_read
 
     # Needed by the search events permission because a permission_action must
     # be provided to create_search(), but the event search is already protected
